@@ -1,8 +1,5 @@
 package CPANPLUS::Internals::Source::MetaCPAN;
-{
-  $CPANPLUS::Internals::Source::MetaCPAN::VERSION = '0.08';
-}
-
+$CPANPLUS::Internals::Source::MetaCPAN::VERSION = '0.10';
 #ABSTRACT: MetaCPAN source implementation
 
 use strict;
@@ -18,7 +15,7 @@ use Params::Check               qw[allow check];
 use Locale::Maketext::Simple    Class => 'CPANPLUS', Style => 'gettext';
 use Module::Load::Conditional   qw[check_install];
 
-use constant METACPAN => 'http://api.metacpan.org/';
+use constant METACPAN => 'http://fastapi.metacpan.org/';
 
 {
     my $metacpan = METACPAN;
@@ -168,13 +165,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 CPANPLUS::Internals::Source::MetaCPAN - MetaCPAN source implementation
 
 =head1 VERSION
 
-version 0.08
+version 0.10
 
 =head1 SYNOPSIS
 
@@ -225,7 +224,7 @@ Chris Williams <chris@bingosnet.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Chris Williams and Jos Boumans.
+This software is copyright (c) 2017 by Chris Williams and Jos Boumans.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
